	
#version 330

in vec2 fragmentUV;
in vec3 P;
in vec3 N;
in vec3 V;
in vec3 C;

out vec4 fragColor;

uniform sampler2D colorTexture;

uniform vec3 lightPosition;
uniform vec3 diffuseColor;
uniform vec3 lightIntensity;

void main() {

	//vec3 textureColor = texture(colorTexture, fragmentUV).rgb;

	vec3 diffuseColor_ = diffuseColor * C;
	// Blinn Illumination Model:

	float shininess = 200;
	vec3 specular = vec3(1.0,1.0,1.0);

	// L...lightDirection
	vec3 L = normalize(lightPosition - P);
	
	// Il...lightIntensity	
	float d = length(lightPosition - P);

	float kc = 1; // constantAttenuation
	float kl = 0; // linearAttenuation
	float kq = 0; // quadraticAttenuation

	// LightAttennuation
	vec3 Il = ( lightIntensity * (1.0f / (kc + kl*d + kq*d*d)) );

	float diffuseFactor = clamp ( dot( N , L ) , 0 , 1 );
	vec3 H = normalize(V + L);
	
	float cosNH = clamp ( dot( N , H ) , 0 , 1 );
	float specularFactor = diffuseFactor * pow( cosNH , shininess);

	vec3 diffusePart = diffuseColor_ * diffuseFactor;
	vec3 specularPart = specular * specularFactor;
	
	vec3 totalIntensity = Il * (diffusePart + specularPart) + 0.2;

	fragColor = vec4(totalIntensity+C/2,1.0);
}
	
	
