#version 330

in vec3 P;
in vec3 N;

out vec4 fragColor;

uniform vec3 item_color;
uniform float transparency;

const int lightCount = 1;
uniform vec3 lightPositions[lightCount];
uniform vec3 cameraPosition;


uniform vec3 _SpecColor = vec3(1,1,1);
uniform float _Shininess = 200;
uniform vec3 _LightColor0 = vec3(1.0,1.0,1.0);

void main() {

	vec3 normalDirection = normalize(N);

	vec3 viewDirection = normalize(cameraPosition - vec3(P));
    vec3 lightDirection;
    float attenuation;

	vec3 ambientLighting =  vec3(0.5f,0.5f,0.5f);

	 // initialize total lighting with ambient lighting
    vec3 totalLighting = ambientLighting;

	for (int index = 0; index < lightCount; index++) { // for all light sources

		vec3 vertexToLightSource = vec3(lightPositions[index] - P);
		float distance = length(vertexToLightSource);
		attenuation = 1.0 / distance; // linear attenuation 
		lightDirection = normalize(vertexToLightSource);
	
		vec3 diffuseReflection = attenuation * vec3(_LightColor0) 
				   * max(0.0, dot(normalDirection, lightDirection));

		 vec3 specularReflection;
				if (dot(normalDirection, lightDirection) < 0.0) 
				   // light source on the wrong side?
				{
				   specularReflection = vec3(0.0, 0.0, 0.0); 
					  // no specular reflection
				}
				else // light source on the right side
				{
				   specularReflection = attenuation * vec3(_LightColor0) 
					  * vec3(_SpecColor) * pow(max(0.0, dot(
					  reflect(-lightDirection, normalDirection), 
					  viewDirection)), _Shininess);
				} 

		totalLighting = totalLighting + diffuseReflection + specularReflection;
	}

	fragColor = vec4(totalLighting,1.0) * vec4(item_color , 1.0);
	fragColor.a = transparency;

}